Struct WeakSender
pub struct WeakSender<T> {
chan: Arc<Chan<T, Semaphore>>,
}Expand description
A sender that does not prevent the channel from being closed.
If all Sender instances of a channel were dropped and only WeakSender
instances remain, the channel is closed.
In order to send messages, the WeakSender needs to be upgraded using
WeakSender::upgrade, which returns Option<Sender>. It returns None
if all Senders have been dropped, and otherwise it returns a Sender.
Examples
use tokio::sync::mpsc::channel;
let (tx, _rx) = channel::<i32>(15);
let tx_weak = tx.downgrade();
// Upgrading will succeed because `tx` still exists.
assert!(tx_weak.upgrade().is_some());
// If we drop `tx`, then it will fail.
drop(tx);
assert!(tx_weak.clone().upgrade().is_none());Fields
chan: Arc<Chan<T, Semaphore>>Implementations
impl<T> WeakSender<T>
impl<T> WeakSender<T>
pub fn upgrade(&self) -> Option<Sender<T>>
pub fn upgrade(&self) -> Option<Sender<T>>
Tries to convert a WeakSender into a Sender. This will return Some
if there are other Sender instances alive and the channel wasn’t
previously dropped, otherwise None is returned.
pub fn strong_count(&self) -> usize
pub fn strong_count(&self) -> usize
Returns the number of Sender handles.
pub fn weak_count(&self) -> usize
pub fn weak_count(&self) -> usize
Returns the number of WeakSender handles.